@@ -1,8 +1,8 @@
-__version__ = "0.2.0"
+__version__ = "0.2.1"
 
 # Import items from sub-modules into sectoolkit namespace
 from .secmeta import (idx, headerfile)
 from .secfiling import (filingDocument, filingArchive)
-from .formparsers import parsers
+from .formparsers import parsers, parser_base
 from .limiter import rate_limiter
 from .utils import get_ticker_name_dicts
\ No newline at end of file
